:github_url: https://github.com/adimian/kirby

Welcome to Kirby documentation!
===============================

.. toctree::
   :maxdepth: 2
   :caption: Notes

   readme

.. toctree::
   :maxdepth: 2
   :caption: Package Reference


.. toctree::
   :maxdepth: 1
   :caption: Miscellaneous

   authors
   changelog

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
